ship_indicators_url = "/ship/indicators"

# {"year":2015,"wdwt":3922.0,"wdwt_percent":40.8,"cgt":1286.0,"cgt_percent":35.1,"ship_indicators":"1","short_name":"中国"}
ship_indicators_field_dict = {"year": "年份", "wdwt": "万载重吨", "wdwt_percent": "万载重吨所占比重",
                      "cgt": "万修正总吨", "cgt_percent": "万修正总吨百分比", "ship_indicators": "造船指标", "short_name": "机构名称"}
