__title__ = 'sharetop'
__version__ = '6.16.21'
__author__ = 'nrliangxy'
__url__ = 'https://github.com/nrliangxy/sharetop'
__author_email__ = 'nrliangxy@foxmail.com'
__keywords__ = ['data', 'finance', 'quant', 'stock', 'fund', 'futures', 'share']
__description__ = 'Provide data related to the economic market'
__project_urls__ = {
    'Source': 'https://github.com/nrliangxy/sharetop',
}
