from .oil_detail import (
    get_oil_reserves,
    get_oil_products,
    get_oil_consumption,
    get_oil_refinerythroughput,
    get_oil_refinerycapacity,
    get_oil_crudeoilpricehistory
)


__all__ = [
    'get_oil_reserves',
    'get_oil_products',
    'get_oil_consumption',
    'get_oil_refinerythroughput',
    'get_oil_refinerycapacity',
    'get_oil_crudeoilpricehistory'
]
