oil_reserves_url = "/oil/reserves"
oil_products_url = "/oil/products"
oil_consumption_url = "/oil/consumption"
oil_refinerythroughput_url = "/oil/refinerythroughput"
oil_refinerycapacity_url = "/oil/refinerycapacity"
oil_crudeoilpricehistory_url = "/oil/crudeoilpricehistory"




oil_reserves_field_dict = {"year": "年份", "num": "储量(十亿桶)", "reserves_pre": "总储量占比",
                      "rp_ratio": "储产比", "short_name": "机构名称", "name": "产品名称",
                      }


oil_products_field_dict = {"year": "年份", "num": "产量(千桶/天)", "product_pre": "总产量占比",
                       "short_name": "机构名称", "name": "产品名称",
                      }


oil_consumption_field_dict = {"year": "年份", "num": "消费量(千桶/天)", "consume_pre": "总产量占比",
                       "short_name": "机构名称", "name": "产品名称",
                      }


oil_refinerythroughput_field_dict = {"year": "年份", "refinery_num": "加工量(千桶/天)", "refinery_pre": "总产量占比",
                       "short_name": "机构名称", "name": "产品名称",
                      }


oil_refinerycapacity_field_dict = {"year": "年份", "capacity_num": "产能(千桶/天)", "capacity_pre": "总产能占比",
                       "short_name": "机构名称", "name": "产品名称",
                      }


oil_crudeoilpricehistory_field_dict = {"year": "年份", "the_day_price": "价格(当年真实价格)", "now_price": "价格(按2022年美国消费者物价指数平减)",
                       "name": "产品名称",
                      }