
url = "https://hq.sinajs.cn/?rn=1694440934177&list=globalbd_{bond_name}"

bond_yield_url = "/bond_yield/kline"


headers = {
            "Referer": "https://stock.finance.sina.com.cn/forex/globalbd/gcny10.html"
        }