user_agent_list = [
    'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.84 Safari/537.36'
]

quote_id_key_list = ["se", "cid"]

fields1_list = ['f1', 'f2', 'f3', 'f4', 'f5', 'f6', 'f7', 'f8', 'f9', 'f10', 'f11', 'f12', 'f13']

k_url_list = ['htt', 'ps:', '//pu', 'sh', '2hi', 's.eas', 'tmon', 'ey.com', '/api', '/q', 't/st', 'ock/k', 'line/get']

# http://push2.eastmoney.com/api/qt/stock/get

real_time_url_list = ['htt', 'ps:', '//pu', 'sh', '2.ea', 'stmon', 'ey.co', 'm/ap', 'i/q', 't/st', 'oc', 'k/g', 'et']

market_real_time_url_list = ['htt', 'p:/', '/pus', 'h2.e', 'ast', 'mon', 'ey.c', 'om/a', 'pi/q', 't/cl', 'ist/g', 'et']

rank_list_list = ['htt', 'p:/', '/dat', 'acen', 'ter-w', 'eb.ea', 'stmo', 'ney.c', 'om/a', 'pi/d', 'ata/', 'v1/g', 'et']

quarterly_report_url_list = ['htt', 'p:/', '/da', 'tac', 'ente', 'r-w', 'eb.e', 'astm', 'oney.', 'co', 'm/ap', 'i/da', 'ta/g', 'et']

one_quarterly_report_url_list = ['htt', 'ps:/', '/dat', 'acen', 'ter', '-we', 'b.ea', 'stmo', 'ney', '.co', 'm/ap', 'i/da', 'ta/v', '1/g', 'et']

bill_url_list = ['htt', 'p:/', '/pus', 'h2h', 'is.e', 'astm', 'oney', '.co', 'm/a', 'pi/', 'qt/', 'sto', 'ck/', 'fflo', 'w/d', 'aykl', 'ine/g', 'et']

# fund_valuation_url_list = ['ht', 'tps:/', '/fun', 'dmob', 'ap', 'i.eas', 'tmon', 'ey.c', 'om/F', 'undM', 'Ap', 'i/Fu', 'ndV', 'arie', 'tieV', 'alua', 'tio', 'nDet', 'ail.', 'ash', 'x?FC', 'ODE=', '{cod', 'e}&d', 'evic', 'eid=', '{devi', 'cei', 'd}&', 'pla', 't=Iph', 'one&A', 'ppTy', 'pe=I', 'pho', 'ne&p', 'rod', 'uct=', 'EFun', 'd&v', 'ersi', 'on=6', '.2.5']

fund_valuation_url_list = ["https://fundgz.1234567.com.cn/js/{code}.js"]
fund_period_change_url = ['htt', 'ps:/', '/fun', 'dmo', 'bap', 'i.ea', 'stm', 'one', 'y.co', 'm/Fu', 'ndMN', 'ewAp', 'i/Fu', 'ndM', 'NPe', 'rio', 'dIn', 'cre', 'ase']

fund_history_url = ['htt', 'ps:/', '/fu', 'ndmo', 'bap', 'i.ea', 'stmo', 'ney.', 'co', 'm/Fu', 'ndM', 'Ne', 'wAp', 'i/Fu', 'ndM', 'NHi', 'sNe', 'tL', 'ist']

fun_types_percentage_url = ['htt', 'ps:/', '/fun', 'dmo', 'bap', 'i.ea', 'stm', 'oney.', 'co', 'm/Fu', 'ndMN', 'ewA', 'pi/', 'Fun', 'dMN', 'Ass', 'etA', 'llo', 'cati', 'onNew']

fund_basic_url = ['htt', 'ps:/', '/fun', 'dmo', 'bap', 'i.ea', 'stm', 'oney', '.co', 'm/Fu', 'ndMN', 'ewA', 'pi/F' ,'undM', 'NNB', 'asic', 'Info', 'rmat', 'ion']

fund_industry_url = ['htt', 'ps:/', '/fun', 'dmo', 'bap', 'i.ea', 'stm', 'one', 'y.co', 'm/Fu', 'ndM', 'NewA', 'pi/', 'Fun', 'dMNS', 'ecto', 'rAl', 'loc', 'ation']

bond_base_list_url = ['htt', 'p:/', '/dat', 'acen', 'ter', '-we', 'b.ea', 'stmo', 'ney', '.co', 'm/a', 'pi/d', 'ata', '/v', '1/g', 'et']

bond_base_info_url = ['htt', 'p:/', '/dat', 'acen', 'ter-w', 'eb.e', 'astm', 'one', 'y.co', 'm/ap', 'i/da', 'ta/v', '1/g', 'et']

stock_base_info_url = ['htt', 'p:/', '/em', 'we', 'b.se', 'curi', 'ties.', 'eas', 'tmon', 'ey.c', 'om/P', 'C_HS', 'F10/C', 'ompa', 'nySu', 'rve', 'y/Pa', 'geAj', 'ax']

base_url_list = ['htt', 'p:/', '/sha', 'ret', 'op.', 'to', 'p/s', 'har', 'eto', 'papi']
# base_url_list = ["http://127.0.0.1:8000/sharetopapi"]


capital_flow_real_time_url_list = ['htt', 'ps:/', '/pu', 'sh2.e', 'astm', 'oney', '.co', 'm/ap', 'i/q', 't/ul', 'ist.', 'np/g', 'et']

sector_url_list = ['htt', 'ps:/', '/pu', 'sh2', '.eas', 'tmon', 'ey.c', 'om/a', 'pi/q', 't/cl', 'ist', '/g', 'et']
