

country_base_url = "/country/data_base"

country_field_dict = {"short_name": "国家简称", "full_name": "国家全称", "en_short_name": "英文简称",
                      "en_full_name": "英文全称", "land_area": "土地面积(万平方公里)", "continent": "所属洲",
                      "country_type": "机构类型", "abbreviation": "国家简称", "capital_cn": "首都(中文)",
                      "capital_en": "首都(英文)", "org_name": "所属组织"}
