EastmoneyFundHeaders = {
    'User-Agent': 'EMProjJijin/6.2.8 (iPhone; iOS 13.6; Scale/2.00)',
    'GTOKEN': '98B423068C1F4DEF9842F82ADF08C5db',
    'clientInfo': 'ttjj-iPhone10,1-iOS-iOS13.6',
    'Content-Type': 'application/x-www-form-urlencoded',
    'Host': 'fundmobapi.eastmoney.com',
    'Referer': 'https://mpservice.com/516939c37bdb4ba2b1138c50cf69a2e1/release/pages/FundHistoryNetWorth',
}


fund_money_cloumns = {
    "SHORTNAME": "基金简称",
    "FCODE": "基金代码",
    "FSRQ": "日期",
    "DWJZ": "万份收益",
    "LJJZ": "年化收益率7日",
    "FTYI": "年化收益率14日",
    "TEYI": "年化收益率28日",
    "SYL_Y": "近1月",
    "SYL_3Y": "近3月",
    "SYL_6Y": "近6月",
    "SYL_1N": "近1年",
    "SYL_2N": "近2年",
    "SYL_3N": "近3年",
    "SYL_5N": "近5年",
    "SYL_JN": "今年来",
    "SYL_LN": "成立来",
    "index": '序号'
}

