car_sales_url = "/car_sales/car_data"

car_sales_field_dict = {
    "rank_list": "排名",
    "car_series": "车系",
    "dealer_min_price": "经销商最低价格",
    "dealer_max_price": "经销商最高价格",
    "maker_min_price": "厂商最低价格",
    "maker_max_price": "厂商最高价格",
    "brand_name": "总品牌",
    "sub_brand_name": "子品牌",
    "sales_volume": "销量",
    "car_type": "汽车类型",
    "pub_date": "公布时间",
    "source": "数据源"
}