STOCK_BASE_INFO_DICT = {"code": '股票代码',
                        "mk_code": '市场代码',
                        "secucode": '唯一代码',
                        "name": '股票名称',
                        "org_name": '公司名称',
                        "org_name_en": '公司英文名称',
                        "org_code": '公司id',
                        "uscc": '统一社会信用代码',
                        "security_type": '证券类别',
                        "trade_market": '上市交易所',
                        "em_industry": '东财行业',
                        "industrycsrc1": '证监会行业',
                        "chairman": '董事长',
                        "legal_person": '法人代表',
                        "president": '总经理',
                        "secretary": '董秘',
                        "secpresent": '证券事务代表',
                        "reg_capital": '注册资本(万)',
                        "found_date": '公司成立日期',
                        "listing_date": '公司上市日期',
                        "province": '所在省份',
                        "city": '所在城市',
                        "introduction": '公司简介',
                        "business_scope": '经营范围',
                        "website": '公司主页',
                        "org_tel": '联系电话',
                        "org_fax": '联系传真',
                        "email": '电子邮件',
                        "reg_address": '注册地址',
                        "office_address": '办公地址',
                        "emp_num": '员工人数',
                        "manager_num": '管理人员人数',
                        "law_office": '律师事务所',
                        "accounting_firm": '会计师事务所',
                        "exchange_code": '交易所代码'}

CAPITAL_FLOW_DICT = {
    "f62": "今日主力净流入",
    "f64": "超大单流入",
    "f65": "超大单流出",
    "f66": "今日超大单净流入",
    "f69": "超大单净比",
    "f70": "大单流入",
    "f71": "大单流出",
    "f72": "今日大单净流入",
    "f75": "大单净比",
    "f76": "中单流入",
    "f77": "中单流出",
    "f78": "今日中单净流入",
    "f81": "中单净比",
    "f82": "小单流入",
    "f83": "小单流出",
    "f84": "今日小单净流入",
    "f87": "小单净比",
    "f184": "主力净比",
    "f278": "5日主力净流入",
    "f279": "5日超大单净流入",
    "f280": "5日大单净流入",
    "f281": "5日中单净流入",
    "f282": "5日小单净流入",
    "f252": "20日主力净流入",
    "f253": "20日超大单净流入",
    "f254": "20日大单净流入",
    "f255": "20日中单净流入",
    "f256": "20日小单净流入"
}